## 0.6.0 - 2023-03-21

### Added

- [#295](https://github.com/edgarrmondragon/citric/issues/295) Implement `set_quota_properties` in client
- [#552](https://github.com/edgarrmondragon/citric/issues/552) Implement `get_available_site_settings` in client
- [#765](https://github.com/edgarrmondragon/citric/issues/765) Use `TypedDict` for more precise `**kwargs` typing
